@@ -59,17 +59,32 @@ test_that("logging functionality", {
 
   mlflow_log_metric("mse", 24)
   mlflow_log_metric("mse", 25)
+  mlflow_log_metric("nan", NaN)
+  mlflow_log_metric("inf", Inf)
+  mlflow_log_metric("-inf", -Inf)
 
   mlflow_set_tag("tag_key", "tag_value")
   mlflow_log_param("param_key", "param_value")
 
   run <- mlflow_get_run()
+  metrics <- run$metrics[[1]]
+  nan_value <- metrics$value[metrics$key == "nan"]
+  expect_true(is.nan(nan_value))
+  pos_inf_value <- metrics$value[metrics$key == "inf"]
+  expect_true(pos_inf_value >= 1.7976931348623157e308)
+  neg_inf_value <- metrics$value[metrics$key == "-inf"]
+  expect_true(neg_inf_value <= -1.7976931348623157e308)
   run_id <- run$run_uuid
   tags <- run$tags[[1]]
   expect_identical("tag_value", tags$value[tags$key == "tag_key"])
   expect_identical(run$params[[1]]$key, "param_key")
   expect_identical(run$params[[1]]$value, "param_value")
 
+  mlflow_delete_tag("tag_key", run_id)
+  run <- mlflow_get_run()
+  tags <- run$tags[[1]]
+  expect_false("tag_key" %in% tags$key)
+
   mlflow_end_run()
   end_time_upper_bound <- Sys.time()
   ended_run <- mlflow_get_run(run_id = run_id)
@@ -249,6 +264,15 @@ test_that("mlflow_search_runs() works", {
   expect_equal(nrow(mlflow_search_runs(filter = "metrics.test > 10", experiment_ids = list("0"))), 1)
   expect_equal(nrow(mlflow_search_runs(filter = "metrics.test < 20", experiment_ids = list("0"))), 1)
   expect_equal(nrow(mlflow_search_runs(filter = "metrics.test > 20", experiment_ids = list("0"))), 0)
+
+  search <- mlflow_search_runs(order_by = "metrics.test", experiment_ids = list("0"))
+  expect_equal(search$metrics[[1]]$value[1], 10)
+  expect_equal(search$metrics[[2]]$value[1], 20)
+
+  search <- mlflow_search_runs(order_by = list("metrics.test DESC"), experiment_ids = list("0"))
+  expect_equal(search$metrics[[1]]$value[1], 20)
+  expect_equal(search$metrics[[2]]$value[1], 10)
+
   mlflow_set_experiment("new-experiment")
   expect_equal(nrow(mlflow_search_runs()), 0)
   with(mlflow_start_run(), {
@@ -276,10 +300,10 @@ test_that("mlflow_log_batch() works", {
   mlflow_clear_test_dir("mlruns")
   mlflow_start_run()
   mlflow_log_batch(
-    metrics = data.frame(key = c("mse", "mse", "rmse", "rmse"),
-                         value = c(21, 23, 42, 36),
-                         timestamp = c(100, 200, 300, 300),
-                         step = c(-4, 1, 7, 3)),
+    metrics = data.frame(key = c("mse", "mse", "rmse", "rmse", "nan", "Inf", "-Inf"),
+                         value = c(21, 23, 42, 36, NaN, Inf, -Inf),
+                         timestamp = c(100, 200, 300, 300, 400, 500, 600),
+                         step = c(-4, 1, 7, 3, 8, 9, 10)),
     params = data.frame(key = c("l1", "optimizer"), value = c(0.01, "adam")),
     tags = data.frame(key = c("model_type", "data_year"),
                       value = c("regression", "2015"))
@@ -292,19 +316,20 @@ test_that("mlflow_log_batch() works", {
 
   expect_setequal(
     metrics$key,
-    c("mse", "rmse")
-  )
-  expect_setequal(
-    metrics$value,
-    c(23, 42)
+    c("mse", "rmse", "nan", "Inf", "-Inf")
   )
+  expect_equal(23, metrics$value[metrics$key == "mse"])
+  expect_equal(42, metrics$value[metrics$key == "rmse"])
+  expect_true(all(is.nan(metrics$value[metrics$key == "nan"])))
+  expect_true(all(1.7976931348623157e308 <= (metrics$value[metrics$key == "Inf"])))
+  expect_true(all(-1.7976931348623157e308 >= (metrics$value[metrics$key == "-Inf"])))
   expect_setequal(
     metrics$timestamp,
-    purrr::map(c(200, 300), mlflow:::milliseconds_to_date)
+    purrr::map(c(200, 300, 400, 500, 600), mlflow:::milliseconds_to_date)
   )
   expect_setequal(
     metrics$step,
-    c(1, 7)
+    c(1, 7, 8, 9, 10)
   )
 
   metric_history <- mlflow_get_metric_history("mse")
